@@ -3,29 +3,15 @@ package Class::Pluggable;
 use 5.008006;
 use strict;
 use warnings;
+use vars qw($AUTOLOAD);
 use Carp;
 
-our $VERSION = '0.021';
+our $VERSION = '0.022';
 
-sub import {
-  my ($self) = @_;
-  my @plugins = ();
-  my $package = __PACKAGE__;
-
-  { ## Create closure that returns array reference for the plugins.
-	no strict "refs";
-	if (not defined &{"${package}::_getPlugins"}) {
-	  *{"${package}::_getPlugins"} = sub {
-		return \@plugins;
-	  }
-	}
-  }
-}
-
-sub addPlugin {
+sub add_plugin {
 	my ($self, $plugin) = @_;
 
-	push @{$self->_getPlugins()}, $plugin;
+	push @{$self->_get_plugins()}, $plugin;
 
 	{
 	  no strict 'refs';
@@ -35,12 +21,25 @@ sub addPlugin {
 }
 
 
-sub getPlugins {
-  return @{$_[0]->_getPlugins()};
+sub _get_plugins {
+  my $self = shift;
+
+  if (not ref $self) {
+    printf "  !! ref = %s\n", $self;
+    croak("Cannot handle the plugins as Class method.");
+  }
+
+  $self->{_PLUGINS} = [] if not $self->{_PLUGINS};
+  return $self->{_PLUGINS};
 }
 
 
-sub addHook {
+sub get_plugins {
+  return @{$_[0]->_get_plugins()};
+}
+
+
+sub add_hook {
   my ($self, $hook, $method) = @_;
 
   if (defined ${$self->{_HOOK}}{$hook}) {
@@ -51,7 +50,7 @@ sub addHook {
 }
 
 
-sub runHook {
+sub run_hook {
   my ($self, $hook) = @_;
   my $method = ${$self->{_HOOK}}{$hook};
 
@@ -60,18 +59,18 @@ sub runHook {
 	croak("The hook ($hook) $caller called doesn't exists.");
   }
 
-  $self->executeAllPluginsMethod($method);
+  $self->execute_all_plugins_method($method);
 }
 
 
 
-sub removeHook {
+sub remove_hook {
   my ($self, $hook) = @_;
   delete ${$self->{_HOOK}}{$hook};
 }
 
 
-sub executePluginMethod {
+sub execute_plugin_method {
 	my ($self, $plugin, $method, @args) = @_;
 	my $result;
 
@@ -85,13 +84,25 @@ sub executePluginMethod {
 	return $result;
 }
 
-sub executeAllPluginsMethod {
+sub execute_all_plugins_method {
   my ($self, $method, @args) = @_;
 
-  $self->executePluginMethod($_, $method, @args)
-	foreach $self->getPlugins();
+  $self->execute_plugin_method($_, $method, @args)
+	foreach $self->get_plugins();
 }
 
+
+
+## Deprecated Methods.
+sub addPlugin { carp("deprecated method."); (shift)->add_plugin(@_) }
+sub _getPlugins { carp("deprecated method."); (shift)->_get_plugins(@_) }
+sub getPlugins { carp("deprecated method."); (shift)->get_plugins(@_) }
+sub addHook { carp("deprecated method."); (shift)->add_hook(@_) }
+sub runHook { carp("deprecated method."); (shift)->run_hook(@_) }
+sub removeHook { carp("deprecated method."); (shift)->remove_hook(@_) }
+sub executePluginMethod { carp("deprecated method."); (shift)->execute_plugin_method(@_) }
+sub executeAllPluginsMethod { carp("deprecated method."); (shift)->execute_all_plugins_method(@_) }
+
 1;
 __END__
 
@@ -105,7 +116,7 @@ Class::Pluggable - Simple pluggable class.
   use base qw(Class::Pluggable);
 
   # Some::Plugin::Module has sub routin called newAction
-  addPlugin("Some::Plugin::Module"); 
+  add_plugin("Some::Plugin::Module"); 
 
   newAction();  # Plugged action.
 
@@ -125,19 +136,19 @@ There are one thing that Plugin developer have to know. The plugin
 module MUST have @EXPORT_AS_PLUGIN to use this pluggable mechanism.
 This works almost same as @EXPORT. But the methods in the
 @EXPORT_AS_PLUGIN wouldn't be exported to your package. But it would
-be exported to the subclass of Class::Pluggable (only when you call addPlugin()).
+be exported to the subclass of Class::Pluggable (only when you call add_plugin()).
 
 And the another meaning of "pluggable" is so called hook-mechanism.
 For example, if you want to allow to other modules to do something
 before and/or after some action. You can do like this:
 
-  $self->executePluginMethod($_, "before_action")
-    foreach $self->getPlugins();
+  $self->execute_plugin_method($_, "before_action")
+    foreach $self->get_plugins();
 
   ## do some your own action here.
 
-  $self->executePluginMethod($_, "after_action")
-    foreach $self->getPlugins();
+  $self->execute_plugin_method($_, "after_action")
+    foreach $self->get_plugins();
 
 =head1 METHODS
 
@@ -145,57 +156,57 @@ Here are all methods of Class::Pluggable.
 
 =over 4
 
-=item addPlugin
+=item add_plugin
 
-  YourClass->addPlugin($pluginName)
+  $object->add_plugin($pluginName)
 
 This will add new plugin to your class. What you added to here
-would be returned by getPlugins() method.
+would be returned by get_plugins() method.
 
-=item getPlugins
+=item get_plugins
 
-  @plugins = YourClass->getPlugins();
+  @plugins = $object->get_plugins();
 
 It will return all of plugin names that are already added to YouClass.
 
-=item executePluginMethod
+=item execute_plugin_method
 
-  $result = YourClass->executePluginMethod("SomePlugin", "someMethod");
+  $result = $object->execute_plugin_method("SomePlugin", "someMethod");
 
 This will execute the method someMethod of SomePlugin.
 
-=item executeAllPluginMethod
+=item execute_all_plugin_method
 
-  YourClass->executeAllPluginMethod("someMethod");
+  $object->execute_all_plugin_method("someMethod");
 
 This will execute the method someMethod of all plugin we have.
 This is almost same as following code.
 
-  $self->executePluginMethod($_, "someMethod")
-    foreach $self->getPlugins();
+  $self->execute_plugin_method($_, "someMethod")
+    foreach $self->get_plugins();
 
 The difference is executeAllPluginMethod can't return any values.
 But executePluginMethod can.
 
-=item addHook
+=item add_hook
 
-  YourClass->addHook("pre-init", "pre_init");
+  $object->add_hook("pre-init", "pre_init");
 
-This will add new hook to your class. Whenever runHook("pre-init") has called,
+This will add new hook to your class. Whenever run_hook("pre-init") has called,
 the method pre_init of all plugins which we have will be executed.
 
-=item runHook
+=item run_hook
 
-  YourClass->runHook("pre-init");
+  $object->run_hook("pre-init");
 
 This will execute the hook-method of all plugins which we have.
 
-=item deleteHook
+=item remove_hook
 
-  YourClass->deleteHook("pre-init");
+  $object->remove_hook("pre-init");
 
 This will delete the hook from YourClass. After calling this method,
-you cannot call runHook("pre-init"). If you do, it will die immediately.
+you cannot call run_hook("pre-init"). If you do, it will die immediately.
 
 =head1 SEE ALSO
 
